summaryrefslogtreecommitdiffstats
path: root/rgx.c
diff options
context:
space:
mode:
Diffstat (limited to 'rgx.c')
-rw-r--r--rgx.c22
1 files changed, 11 insertions, 11 deletions
diff --git a/rgx.c b/rgx.c
index e89564a..0c1c377 100644
--- a/rgx.c
+++ b/rgx.c
@@ -15,26 +15,26 @@
* the Free Software Foundation, 59 Temple Place, Suite 330, Boston, MA 02111, USA.
*
* As a special exception, the Free Software Foundation gives permission
* for additional uses of the text contained in its release of GUILE.
*
* The exception is that, if you link the GUILE library with other files
* to produce an executable, this does not by itself cause the
* resulting executable to be covered by the GNU General Public License.
* Your use of that executable is in no way restricted on account of
* linking the GUILE library code into it.
*
* This exception does not however invalidate any other reasons why
* the executable file might be covered by the GNU General Public License.
*
* This exception applies only to the code released by the
* Free Software Foundation under the name GUILE. If you copy
* code from other Free Software Foundation releases into a copy of
- * GUILE, as the General Public License permits, the exception does
+ * SCM, as the General Public License permits, the exception does
* not apply to the code that you add in this way. To avoid misleading
* anyone as to the status of such modified files, you must delete
* this exception notice from them.
*
* If you write modifications of your own for GUILE, it is your choice
* whether to permit this exception to apply to your modifications.
* If you do not wish that, delete this exception notice.
*/
@@ -55,7 +55,7 @@
#endif
static char rcsid[] =
- "$Id: rgx.c,v 1.12 1999/09/07 16:55:54 jaffer Exp $";
+ "$Id: rgx.c,v 1.15 2002/04/13 20:41:02 jaffer Exp $";
#ifdef HAVE_ALLOCA
# include <alloca.h>
@@ -121,13 +121,13 @@ typedef struct regex_info {
sizet fregex(ptr)
CELLPTR ptr;
{
- regfree(RGX(ptr));
+ regfree(RGX((SCM)ptr));
#ifndef _GNU_SOURCE
/* options are null => we compiled the anchored pattern */
- if (RGX_INFO(ptr)->options==0)
- regfree(RGX2(ptr));
+ if (RGX_INFO((SCM)ptr)->options==0)
+ regfree(RGX2((SCM)ptr));
#endif
- must_free(CHARS(ptr), (sizet)LENGTH(ptr));
+ must_free(CHARS((SCM)ptr), (sizet)LENGTH((SCM)ptr));
return 0;
}
@@ -15,26 +15,26 @@
*
* As a special exception, the Free Software Foundation gives permission
- * for additional uses of the text contained in its release of GUILE.
+ * for additional uses of the text contained in its release of SCM.
*
@@ -15,26 +15,26 @@
*
- * The exception is that, if you link the GUILE library with other files
+ * The exception is that, if you link the SCM library with other files
* to produce an executable, this does not by itself cause the
* resulting executable to be covered by the GNU General Public License.
@@ -15,26 +15,26 @@
* resulting executable to be covered by the GNU General Public License.
* Your use of that executable is in no way restricted on account of
- * linking the GUILE library code into it.
+ * linking the SCM library code into it.
*
* This exception does not however invalidate any other reasons why
@@ -15,26 +15,26 @@
*
* This exception applies only to the code released by the
- * Free Software Foundation under the name GUILE. If you copy
+ * Free Software Foundation under the name SCM. If you copy
* code from other Free Software Foundation releases into a copy of
@@ -15,26 +15,26 @@
* this exception notice from them.
*
- * If you write modifications of your own for GUILE, it is your choice
+ * If you write modifications of your own for SCM, it is your choice
* whether to permit this exception to apply to your modifications.
* If you do not wish that, delete this exception notice.